==> jc-1.4.0.tar.gz: java/util/zip/DeflaterOutputStream.h <==
// public class java.util.zip.DeflaterOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f80e6f4ae1ff7e14 java_util_zip_DeflaterOutputStream

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_java_util_zip_DeflaterOutputStream_H_
#define _JC_java_util_zip_DeflaterOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_Deflater$object;

// Typedefs
typedef struct _jc_java_util_zip_DeflaterOutputStream$sub_refs	_jc_java_util_zip_DeflaterOutputStream$sub_refs;
typedef struct _jc_java_util_zip_DeflaterOutputStream$sub_nonrefs	_jc_java_util_zip_DeflaterOutputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_DeflaterOutputStream$refs	_jc_java_util_zip_DeflaterOutputStream$refs;
typedef struct _jc_java_util_zip_DeflaterOutputStream$nonrefs	_jc_java_util_zip_DeflaterOutputStream$nonrefs;
typedef struct _jc_java_util_zip_DeflaterOutputStream$object	_jc_java_util_zip_DeflaterOutputStream$object;

typedef const struct _jc_java_util_zip_DeflaterOutputStream$vmethods	_jc_java_util_zip_DeflaterOutputStream$vmethods;
typedef const struct _jc_java_util_zip_DeflaterOutputStream$vtable	_jc_java_util_zip_DeflaterOutputStream$vtable;
typedef const struct _jc_java_util_zip_DeflaterOutputStream$vtype	_jc_java_util_zip_DeflaterOutputStream$vtype;

// Constructors
extern void _jc_java_util_zip_DeflaterOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, struct _jc_java_io_OutputStream$object *);
extern void _jc_java_util_zip_DeflaterOutputStream$method$_init$c6123f9b3216a160(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_java_util_zip_Deflater$object *);
extern void _jc_java_util_zip_DeflaterOutputStream$method$_init$9f549024c35091fb(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_java_util_zip_Deflater$object *, jint);

// Virtual methods
extern void _jc_java_util_zip_DeflaterOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *);
extern void _jc_java_util_zip_DeflaterOutputStream$method$deflate$64a3ce92946f522b(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *);
extern void _jc_java_util_zip_DeflaterOutputStream$method$finish$8d1c944274527186(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *);
extern void _jc_java_util_zip_DeflaterOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *);
extern void _jc_java_util_zip_DeflaterOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, jint);
extern void _jc_java_util_zip_DeflaterOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_DeflaterOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_util_zip_DeflaterOutputStream$method_info$deflate$64a3ce92946f522b;
extern _jc_method _jc_java_util_zip_DeflaterOutputStream$method_info$finish$8d1c944274527186;
extern _jc_method _jc_java_util_zip_DeflaterOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_util_zip_DeflaterOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_util_zip_DeflaterOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_util_zip_DeflaterOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *);
	void	(*deflate$64a3ce92946f522b)(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *);
	void	(*finish$8d1c944274527186)(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *);
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, jint);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_java_util_zip_DeflaterOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_util_zip_DeflaterOutputStream$vmethods	java_util_zip_DeflaterOutputStream;
};

// Vtype
struct _jc_java_util_zip_DeflaterOutputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_DeflaterOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_DeflaterOutputStream$sub_refs {
	_jc_byte_array	*buf;
	struct _jc_java_util_zip_Deflater$object	*def;
};

// Reference instance fields (object)
struct _jc_java_util_zip_DeflaterOutputStream$refs {
    _jc_java_util_zip_DeflaterOutputStream$sub_refs	java_util_zip_DeflaterOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_DeflaterOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_DeflaterOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_nonrefs	java_util_zip_DeflaterOutputStream;
};

// Object instance structure
struct _jc_java_util_zip_DeflaterOutputStream$object {
	_jc_java_util_zip_DeflaterOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_DeflaterOutputStream$vtype	*vtype;
	_jc_java_util_zip_DeflaterOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_DeflaterOutputStream$vtype _jc_java_util_zip_DeflaterOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_DeflaterOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_DeflaterOutputStream$class_object;

#endif	/* _JC_java_util_zip_DeflaterOutputStream_H_ */

==> jc-1.4.6.tar.gz: java/util/zip/DeflaterOutputStream.h <==
// public class java.util.zip.DeflaterOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f80e6f4ae1ff7e14 java_util_zip_DeflaterOutputStream

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_java_util_zip_DeflaterOutputStream_H_
#define _JC_java_util_zip_DeflaterOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_Deflater$object;

// Typedefs
typedef struct _jc_java_util_zip_DeflaterOutputStream$sub_refs	_jc_java_util_zip_DeflaterOutputStream$sub_refs;
typedef struct _jc_java_util_zip_DeflaterOutputStream$sub_nonrefs	_jc_java_util_zip_DeflaterOutputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_DeflaterOutputStream$refs	_jc_java_util_zip_DeflaterOutputStream$refs;
typedef struct _jc_java_util_zip_DeflaterOutputStream$nonrefs	_jc_java_util_zip_DeflaterOutputStream$nonrefs;
typedef struct _jc_java_util_zip_DeflaterOutputStream$object	_jc_java_util_zip_DeflaterOutputStream$object;

typedef const struct _jc_java_util_zip_DeflaterOutputStream$vmethods	_jc_java_util_zip_DeflaterOutputStream$vmethods;
typedef const struct _jc_java_util_zip_DeflaterOutputStream$vtable	_jc_java_util_zip_DeflaterOutputStream$vtable;
typedef const struct _jc_java_util_zip_DeflaterOutputStream$vtype	_jc_java_util_zip_DeflaterOutputStream$vtype;

// Constructors
extern void _jc_java_util_zip_DeflaterOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_DeflaterOutputStream$method$_init$c6123f9b3216a160(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_java_util_zip_Deflater$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_DeflaterOutputStream$method$_init$9f549024c35091fb(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_java_util_zip_Deflater$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_zip_DeflaterOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_DeflaterOutputStream$method$deflate$64a3ce92946f522b(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_DeflaterOutputStream$method$finish$8d1c944274527186(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_DeflaterOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_DeflaterOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_DeflaterOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_DeflaterOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_util_zip_DeflaterOutputStream$method_info$deflate$64a3ce92946f522b;
extern _jc_method _jc_java_util_zip_DeflaterOutputStream$method_info$finish$8d1c944274527186;
extern _jc_method _jc_java_util_zip_DeflaterOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_util_zip_DeflaterOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_util_zip_DeflaterOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_util_zip_DeflaterOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *) _JC_JCNI_ATTR;
	void	(*deflate$64a3ce92946f522b)(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *) _JC_JCNI_ATTR;
	void	(*finish$8d1c944274527186)(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *) _JC_JCNI_ATTR;
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_util_zip_DeflaterOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_zip_DeflaterOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_util_zip_DeflaterOutputStream$vmethods	java_util_zip_DeflaterOutputStream;
};

// Vtype
struct _jc_java_util_zip_DeflaterOutputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_DeflaterOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_DeflaterOutputStream$sub_refs {
	_jc_byte_array	*buf;
	struct _jc_java_util_zip_Deflater$object	*def;
};

// Reference instance fields (object)
struct _jc_java_util_zip_DeflaterOutputStream$refs {
    _jc_java_util_zip_DeflaterOutputStream$sub_refs	java_util_zip_DeflaterOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_DeflaterOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_DeflaterOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_nonrefs	java_util_zip_DeflaterOutputStream;
};

// Object instance structure
struct _jc_java_util_zip_DeflaterOutputStream$object {
	_jc_java_util_zip_DeflaterOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_DeflaterOutputStream$vtype	*vtype;
	_jc_java_util_zip_DeflaterOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_DeflaterOutputStream$vtype _jc_java_util_zip_DeflaterOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_DeflaterOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_DeflaterOutputStream$class_object;

#endif	/* _JC_java_util_zip_DeflaterOutputStream_H_ */
